==> green-core-1.70.1.tgz: package/components/context-menu/context-menu.component.js <==
import {
  __decorateClass,
  __privateAdd,
  __privateGet,
  __privateMethod
} from "../../chunks/chunk.QTSIPXV3.js";
var _renderPopover, _handleItemClick, handleItemClick_fn;
import { localized, msg } from "@lit/localize";
import { nothing } from "lit";
import { property, queryAsync } from "lit/decorators.js";
import { classMap } from "lit/directives/class-map.js";
import { when } from "lit/directives/when.js";
import { GdsElement } from "../../gds-element";
import { GdsMenuItem } from "../../primitives/menu/menu-item.component";
import { GdsMenu } from "../../primitives/menu/menu.component";
import { tokens } from "../../tokens.style";
import { TransitionalStyles } from "../../transitional-styles";
import {
  gdsCustomElement,
  html
} from "../../utils/helpers/custom-element-scoping";
import {
  withLayoutChildProps,
  withMarginProps
} from "../../utils/mixins/declarative-layout-mixins";
import { GdsPopover } from "../popover/popover.component";
import styles from "./context-menu.styles";
import { GdsMenuHeading } from "../../primitives/menu/menu-heading.component";
let GdsContextMenu = class extends withMarginProps(
  withLayoutChildProps(GdsElement)
) {
  constructor() {
    super(...arguments);
    __privateAdd(this, _handleItemClick);
    this.open = false;
    this.buttonLabel = msg("Open context menu");
    this.showLabel = false;
    this.label = "";
    this.placement = "bottom-start";
    __privateAdd(this, _renderPopover, () => {
      return html`<gds-popover
      id="menu"
      autofocus
      .open=${this.open}
      .triggerRef=${this.elTriggerBtn}
      .anchorRef=${this.elTriggerBtn}
      .label=${this.label}
      .placement=${this.placement}
      @gds-ui-state=${(e) => this.open = e.detail.open}
    >
      <gds-menu
        aria-label=${this.label ?? this.buttonLabel}
        @gds-menu-item-click=${__privateMethod(this, _handleItemClick, handleItemClick_fn)}
      >
        <slot></slot>
      </gds-menu>
    </gds-popover>`;
    });
  }
  connectedCallback() {
    super.connectedCallback();
    TransitionalStyles.instance.apply(this, "gds-context-menu");
    this.addEventListener("keydown", (e) => {
      if (this.open && e.key == "Tab") {
        e.preventDefault();
        this.open = false;
        this.elTriggerBtn.then((el) => el.focus());
      }
    });
  }
  render() {
    return html`<button
        id="trigger"
        class="icon border-0 small ${classMap({ highlighted: this.open })}"
        aria-label=${this.buttonLabel ?? this.label}
        aria-haspopup="menu"
        aria-controls="menu"
        aria-expanded=${this.open}
        @click=${() => this.open = true}
      >
        <slot name="trigger">
          ${this.showLabel ? this.buttonLabel ?? this.label : nothing}
          <svg width="24" height="24" viewBox="0 0 24 24">
            <path
              d="M14 12C14 13.1042 13.1042 14 12 14C10.8958 14 10 13.1042 10 12C10 10.8958 10.8958 10 12 10C13.1042 10 14 10.8958 14 12ZM19 10C17.8958 10 17 10.8958 17 12C17 13.1042 17.8958 14 19 14C20.1042 14 21 13.1042 21 12C21 10.8958 20.1042 10 19 10ZM5 10C3.89583 10 3 10.8958 3 12C3 13.1042 3.89583 14 5 14C6.10417 14 7 13.1042 7 12C7 10.8958 6.10417 10 5 10Z"
              fill="#353531"
            />
          </svg>
        </slot>
      </button>
      ${when(this.open, __privateGet(this, _renderPopover))}`;
  }
};
_renderPopover = new WeakMap();
_handleItemClick = new WeakSet();
handleItemClick_fn = function() {
  this.open = false;
};
GdsContextMenu.styles = [tokens, styles];
GdsContextMenu.shadowRootOptions = {
  mode: "open",
  delegatesFocus: true
};
__decorateClass([
  property({ type: Boolean, reflect: true })
], GdsContextMenu.prototype, "open", 2);
__decorateClass([
  property({
    attribute: "button-label"
  })
], GdsContextMenu.prototype, "buttonLabel", 2);
__decorateClass([
  property({
    attribute: "show-label",
    type: Boolean
  })
], GdsContextMenu.prototype, "showLabel", 2);
__decorateClass([
  property()
], GdsContextMenu.prototype, "label", 2);
__decorateClass([
  property()
], GdsContextMenu.prototype, "placement", 2);
__decorateClass([
  queryAsync("#trigger")
], GdsContextMenu.prototype, "elTriggerBtn", 2);
GdsContextMenu = __decorateClass([
  gdsCustomElement("gds-context-menu", {
    dependsOn: [GdsMenuItem, GdsMenu, GdsPopover]
  }),
  localized()
], GdsContextMenu);
export {
  GdsContextMenu,
  GdsMenuHeading,
  GdsMenuItem
};

==> green-core-1.71.0.tgz: package/components/context-menu/context-menu.component.js <==
import {
  __decorateClass,
  __privateAdd,
  __privateGet,
  __privateMethod
} from "../../chunks/chunk.QTSIPXV3.js";
var _renderPopover, _handleItemClick, handleItemClick_fn;
import { localized, msg } from "@lit/localize";
import { nothing } from "lit";
import { property, queryAsync } from "lit/decorators.js";
import { classMap } from "lit/directives/class-map.js";
import { when } from "lit/directives/when.js";
import { GdsElement } from "../../gds-element.js";
import { GdsMenuItem } from "../../primitives/menu/menu-item.component.js";
import { GdsMenu } from "../../primitives/menu/menu.component.js";
import { tokens } from "../../tokens.style";
import { TransitionalStyles } from "../../transitional-styles.js";
import {
  gdsCustomElement,
  html
} from "../../utils/helpers/custom-element-scoping.js";
import {
  withLayoutChildProps,
  withMarginProps
} from "../../utils/mixins/declarative-layout-mixins.js";
import { GdsPopover } from "../popover/popover.component.js";
import styles from "./context-menu.styles";
import { GdsMenuHeading } from "../../primitives/menu/menu-heading.component.js";
let GdsContextMenu = class extends withMarginProps(
  withLayoutChildProps(GdsElement)
) {
  constructor() {
    super(...arguments);
    __privateAdd(this, _handleItemClick);
    this.open = false;
    this.buttonLabel = msg("Open context menu");
    this.showLabel = false;
    this.label = "";
    this.placement = "bottom-start";
    __privateAdd(this, _renderPopover, () => {
      return html`<gds-popover
      id="menu"
      autofocus
      .open=${this.open}
      .triggerRef=${this.elTriggerBtn}
      .anchorRef=${this.elTriggerBtn}
      .label=${this.label}
      .placement=${this.placement}
      @gds-ui-state=${(e) => this.open = e.detail.open}
    >
      <gds-menu
        aria-label=${this.label ?? this.buttonLabel}
        @gds-menu-item-click=${__privateMethod(this, _handleItemClick, handleItemClick_fn)}
      >
        <slot></slot>
      </gds-menu>
    </gds-popover>`;
    });
  }
  connectedCallback() {
    super.connectedCallback();
    TransitionalStyles.instance.apply(this, "gds-context-menu");
    this.addEventListener("keydown", (e) => {
      if (this.open && e.key == "Tab") {
        e.preventDefault();
        this.open = false;
        this.elTriggerBtn.then((el) => el.focus());
      }
    });
  }
  render() {
    return html`<button
        id="trigger"
        class="icon border-0 small ${classMap({ highlighted: this.open })}"
        aria-label=${this.buttonLabel ?? this.label}
        aria-haspopup="menu"
        aria-controls="menu"
        aria-expanded=${this.open}
        @click=${() => this.open = true}
      >
        <slot name="trigger">
          ${this.showLabel ? this.buttonLabel ?? this.label : nothing}
          <svg width="24" height="24" viewBox="0 0 24 24">
            <path
              d="M14 12C14 13.1042 13.1042 14 12 14C10.8958 14 10 13.1042 10 12C10 10.8958 10.8958 10 12 10C13.1042 10 14 10.8958 14 12ZM19 10C17.8958 10 17 10.8958 17 12C17 13.1042 17.8958 14 19 14C20.1042 14 21 13.1042 21 12C21 10.8958 20.1042 10 19 10ZM5 10C3.89583 10 3 10.8958 3 12C3 13.1042 3.89583 14 5 14C6.10417 14 7 13.1042 7 12C7 10.8958 6.10417 10 5 10Z"
              fill="#353531"
            />
          </svg>
        </slot>
      </button>
      ${when(this.open, __privateGet(this, _renderPopover))}`;
  }
};
_renderPopover = new WeakMap();
_handleItemClick = new WeakSet();
handleItemClick_fn = function() {
  this.open = false;
};
GdsContextMenu.styles = [tokens, styles];
GdsContextMenu.shadowRootOptions = {
  mode: "open",
  delegatesFocus: true
};
__decorateClass([
  property({ type: Boolean, reflect: true })
], GdsContextMenu.prototype, "open", 2);
__decorateClass([
  property({
    attribute: "button-label"
  })
], GdsContextMenu.prototype, "buttonLabel", 2);
__decorateClass([
  property({
    attribute: "show-label",
    type: Boolean
  })
], GdsContextMenu.prototype, "showLabel", 2);
__decorateClass([
  property()
], GdsContextMenu.prototype, "label", 2);
__decorateClass([
  property()
], GdsContextMenu.prototype, "placement", 2);
__decorateClass([
  queryAsync("#trigger")
], GdsContextMenu.prototype, "elTriggerBtn", 2);
GdsContextMenu = __decorateClass([
  gdsCustomElement("gds-context-menu", {
    dependsOn: [GdsMenuItem, GdsMenu, GdsPopover]
  }),
  localized()
], GdsContextMenu);
export {
  GdsContextMenu,
  GdsMenuHeading,
  GdsMenuItem
};
